@@ -3,7 +3,6 @@
 from .cdq_learning import ClippedDoubleQLearning
 from .cdq_learning import DynaSoftCDQLearning
 from .cdq_learning import SoftCDQLearning
-from .daml import DPGAwareModelLearning
 from .isfv_iteration import ISFittedVIteration
 from .isfv_iteration import ISSoftVIteration
 from .mage import MAGE
@@ -13,8 +12,8 @@ from .maximum_entropy import MaximumEntropyDual
 from .mle import MaximumLikelihood
 from .mle import ModelEnsembleMLE
 from .paml import SPAML
+from .policy_gradient import ActionDPG
 from .policy_gradient import DeterministicPolicyGradient
-from .policy_gradient import ModelAwareDPG
 from .policy_gradient import ReparameterizedSoftPG
 from .svg import OneStepSoftSVG
 from .svg import OneStepSVG
@@ -23,8 +22,8 @@ from .svg import TrajectorySVG
 
 __all__ = [
     "ClippedDoubleQLearning",
+    "ActionDPG",
     "DeterministicPolicyGradient",
-    "DPGAwareModelLearning",
     "ISFittedVIteration",
     "ISSoftVIteration",
     "MaximumEntropyDual",
@@ -32,7 +31,6 @@ __all__ = [
     "DAPO",
     "MAPO",
     "MaximumLikelihood",
-    "ModelAwareDPG",
     "ModelEnsembleMLE",
     "PAML",
     "OneStepSVG",
